Permit

Struct Permit 

pub struct Permit<'a, T> { /* private fields */ }
A borrowing permit to send one value into the channel.

Implementations

Source

impl<T> Permit<'_, T>

pub fn send(self, elem: T)

Sends a value using the reserved capacity.

Since the capacity has been reserved beforehand, the value is sent immediately and the permit is consumed. This will succeed even if the channel has been closed.